@@ -2,7 +2,7 @@ from tfe_run_wait.cli import _apply
 
 
 def main():
-    _apply()
+    exit(_apply())
 
 
 if __name__ == "__main__":
